import 'package:flutter/material.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';
import 'package:syncrow_web/utils/style.dart';

Future<void> showPopUpFilterMenu({
  required BuildContext context,
  Function()? onSortAtoZ,
  Function()? onSortZtoA,
  Function()? cancelButton,
  required Map<String, bool> checkboxStates,
  required RelativeRect position,
  Function()? onOkPressed,
  List<String>? list,
}) async {


  await showMenu(
    context: context,
    position:position,
    
  
    color: ColorsManager.whiteColors,
    shape: const RoundedRectangleBorder(
      borderRadius: BorderRadius.all(Radius.circular(10)),
    ),
    items: <PopupMenuEntry>[
      PopupMenuItem(
        onTap: onSortAtoZ,
        child: ListTile(
          leading: Image.asset(
            Assets.AtoZIcon,
            width: 25,
          ),
          title: const Text(
            "Sort A to Z",
            style: TextStyle(color: Colors.blueGrey),
          ),
        ),
      ),
      PopupMenuItem(
        onTap: onSortZtoA,
        child: ListTile(
          leading: Image.asset(
            Assets.ZtoAIcon,
            width: 25,
          ),
          title: const Text(
            "Sort Z to A",
            style: TextStyle(color: Colors.blueGrey),
          ),
        ),
      ),
      const PopupMenuDivider(),
      const PopupMenuItem(
          child: Text(
        "Filter by Status",
        style: TextStyle(fontWeight: FontWeight.bold),
      )
          // Container(
          //   decoration: containerDecoration.copyWith(
          //       boxShadow: [],
          //       borderRadius: const BorderRadius.only(
          //           topLeft: Radius.circular(10), topRight: Radius.circular(10))),
          //   child: Padding(
          //     padding: const EdgeInsets.all(8.0),
          //     child: TextFormField(
          //       onChanged: onTextFieldChanged,
          //       style: const TextStyle(color: Colors.black),
          //       decoration: textBoxDecoration(radios: 15)!.copyWith(
          //         fillColor: ColorsManager.whiteColors,
          //         errorStyle: const TextStyle(height: 0),
          //         hintStyle: context.textTheme.titleSmall?.copyWith(
          //           color: Colors.grey,
          //           fontSize: 12,
          //         ),
          //         hintText: 'Search',
          //         suffixIcon: SizedBox(
          //           child: SvgPicture.asset(
          //             Assets.searchIconUser,
          //             fit: BoxFit.none,
          //           ),
          //         ),
          //       ),
          //       // "Filter by Status",
          //       // style: TextStyle(fontWeight: FontWeight.bold),
          //     ),
          //   ),
          // ),
          ),
      PopupMenuItem(
        child: Container(
          decoration: containerDecoration.copyWith(
              boxShadow: [],
              borderRadius: const BorderRadius.only(
                  bottomLeft: Radius.circular(10),
                  bottomRight: Radius.circular(10))),
          padding: const EdgeInsets.all(10),
          height: 200,
          width: 400,
          child: Container(
            padding: const EdgeInsets.all(10),
            color: Colors.white,
            child: ListView.builder(
              itemCount: list?.length ?? 0,
              itemBuilder: (context, index) {
                final item = list![index];
                return CheckboxListTile(
                  dense: true,
                  title: Text(item),
                  value: checkboxStates[item],
                  onChanged: (bool? newValue) {
                    checkboxStates[item] = newValue ?? false;
                    (context as Element).markNeedsBuild();
                  },
                );
              },
            ),
          ),
        ),
      ),
      PopupMenuItem(
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            GestureDetector(
              onTap: () {
                Navigator.of(context).pop(); // Close the menu
              },
              child: const Text("Cancel"),
            ),
            GestureDetector(
              onTap: onOkPressed,
              child: const Text(
                "OK",
                style: TextStyle(
                  color: ColorsManager.spaceColor,
                ),
              ),
            ),
          ],
        ),
      ),
    ],
  );
}
